@@ -65,6 +65,10 @@ CAMLprim value bigstring_init_stub(value __unused v_unit) {
      Sadly, it nowadays employs a heuristic that may change this value
      dynamically.  The call to mallopt suppresses this behavior, which
      made it hard to prevent C-heap fragmentation (e.g. in the writer).
+
+     [Async_unix.{Reader,Writer}] intentionally allocate buffers equal to or
+     larger than this limit by default to ensure they get mmap allocated
+     buffers.
   */
   mallopt(M_MMAP_THRESHOLD, 131072);
 #endif
@@ -743,7 +747,7 @@ CAMLprim value bigstring_sendmsg_nonblocking_no_sigpipe_stub(value v_fd,
   int count = Int_val(v_count);
   size_t total_len = 0;
   struct iovec *iovecs = copy_iovecs(&total_len, v_iovecs, count);
-  struct msghdr msghdr = {NULL, 0, NULL, 0, NULL, 0, 0};
+  struct msghdr msghdr = {NULL};
   ssize_t ret;
   if (total_len > THREAD_IO_CUTOFF || contains_mmapped(v_iovecs, count)) {
     Begin_roots1(v_iovecs);
