@@ -51,6 +51,32 @@ let%test_module "[Timerfd]" =
   end)
 ;;
 
+let%test_module "[Memfd]" =
+  (module struct
+    open Memfd
+
+    let%test_unit "[create] returns file descriptors that look correct in \
+                   [/proc/self/fd/...] and are the right size"
+      =
+      match create with
+      | Error _ -> ()
+      | Ok create ->
+        let name = "foo" in
+        let initial_size = 4096 * 2 in
+        let fd =
+          create ~flags:Flags.(cloexec + allow_sealing) ~initial_size name
+          |> to_file_descr
+        in
+        let basename =
+          Unix.readlink [%string "/proc/self/fd/%{fd#File_descr}"] |> Filename.basename
+        in
+        assert (String.(basename = [%string "memfd:%{name} (deleted)"]));
+        assert (Int64.((Unix.fstat fd).st_size = of_int initial_size));
+        Unix.close fd
+    ;;
+  end)
+;;
+
 let%test_unit _ =
   match cores with
   | Error _ -> ()
@@ -167,11 +193,11 @@ let%test_module _ =
             Thread.create
               ~on_uncaught_exn:`Print_to_stderr
               (fun () ->
-                 let nr =
-                   Bigstring_unix.read r (Bigstring.create r_len) ~pos:0 ~len:r_len
-                 in
-                 assert (nr > 0 && nr <= r_len);
-                 Unix.close r)
+                let nr =
+                  Bigstring_unix.read r (Bigstring.create r_len) ~pos:0 ~len:r_len
+                in
+                assert (nr > 0 && nr <= r_len);
+                Unix.close r)
               ()
           in
           let nw =
@@ -192,6 +218,25 @@ let%test_module _ =
                 saw_fd := true);
               assert !saw_fd))
     ;;
+
+    let%test_unit "epoll removes a file descriptor from tracking even if it gets EBADFD" =
+      with_epoll ~f:(fun epoll ->
+        let r, w = Unix.pipe () in
+        Epoll.set epoll w Epoll.Flags.out;
+        Unix.close r;
+        Unix.close w;
+        (* It is bad to close a FD before removing it from epoll, and it raises *)
+        (match Epoll.remove epoll w with
+         | () -> assert false
+         | exception Unix.Unix_error (EBADF, _, _) -> ());
+        (* Even though the above failed, the FD should be removed from the tracking set.
+           When the FD numbers are reused below, they should work fine. *)
+        let r, w = Unix.pipe () in
+        Epoll.set epoll w Epoll.Flags.out;
+        Epoll.remove epoll w;
+        Unix.close r;
+        Unix.close w)
+    ;;
   end)
 ;;
 
@@ -256,7 +301,8 @@ let%expect_test "[Epoll.Expert.clear_ready]" =
       print_num_ready ();
       [%expect {|
         (!num_ready 1)
-        (!num_ready 0) |}])
+        (!num_ready 0)
+        |}])
 ;;
 
 (* Eventfd *)
@@ -344,7 +390,8 @@ let%test_module "getpriority and setpriority" =
         1
         2
         3
-        4 |}];
+        4
+        |}];
       setpriority starting_priority;
       print_s
         [%sexp ([%equal: Linux_ext.Priority.t] starting_priority (getpriority ()) : bool)];
@@ -435,10 +482,10 @@ let%test_unit "get_terminal_size" =
         (Filename_unix.temp_file "get_terminal_size" "")
         ~finally:Unix.unlink
         ~f:(fun fname ->
-          protectx
-            (Unix.openfile fname ~mode:[ Unix.O_RDONLY ] ~perm:0)
-            ~finally:Unix.close
-            ~f)
+        protectx
+          (Unix.openfile fname ~mode:[ Unix.O_RDONLY ] ~perm:0)
+          ~finally:Unix.close
+          ~f)
     in
     (match with_tmp_fd (fun fd -> f (`Fd fd)) with
      | exception Unix.Unix_error (ENOTTY, _, _) -> ()
@@ -469,14 +516,22 @@ let%test_module "getxattr and setxattr" =
       Unix.unlink tmpfile
     ;;
 
-    let get_and_print ~path ~name =
-      let value = (Extended_file_attributes.getxattr |> ok_exn) ~path ~name in
+    let get_and_print ~follow_symlinks ~path ~name =
+      let value =
+        (Extended_file_attributes.getxattr |> ok_exn) ~follow_symlinks ~path ~name
+      in
       print_s [%sexp (value : Extended_file_attributes.Get_attr_result.t)]
     ;;
 
-    let set_and_print ?how ~path ~name ~value () =
+    let set_and_print ?how ~follow_symlinks ~path ~name ~value () =
       let result =
-        (Extended_file_attributes.setxattr |> ok_exn) ?how ~path ~name ~value ()
+        (Extended_file_attributes.setxattr |> ok_exn)
+          ?how
+          ~follow_symlinks
+          ~path
+          ~name
+          ~value
+          ()
       in
       print_s [%sexp (result : Extended_file_attributes.Set_attr_result.t)]
     ;;
@@ -484,21 +539,63 @@ let%test_module "getxattr and setxattr" =
     let%expect_test "simple test" =
       with_tmpfile (fun path ->
         let name = "user.foo" in
-        get_and_print ~path ~name;
+        get_and_print ~follow_symlinks:true ~path ~name;
         [%expect {| ENOATTR |}];
-        set_and_print ~path ~name ~value:"bar" ();
+        set_and_print ~follow_symlinks:true ~path ~name ~value:"bar" ();
         [%expect {| Ok |}];
-        get_and_print ~path ~name;
+        get_and_print ~follow_symlinks:true ~path ~name;
         [%expect {| (Ok bar) |}])
     ;;
 
+    let%expect_test "symlink test" =
+      with_tmpfile (fun path ->
+        let symlink_to_path = path ^ ".symlink" in
+        Unix.symlink ~target:path ~link_name:symlink_to_path;
+        let name = "user.foo" in
+        get_and_print ~follow_symlinks:false ~path:symlink_to_path ~name;
+        [%expect {| ENOATTR |}];
+        get_and_print ~follow_symlinks:true ~path:symlink_to_path ~name;
+        [%expect {| ENOATTR |}];
+        expect_error (fun () ->
+          set_and_print ~follow_symlinks:false ~path:symlink_to_path ~name ~value:"baz" ());
+        [%expect
+          {|
+          (Unix.Unix_error
+           "Operation not permitted"
+           lsetxattr
+           temporary-file-for-testing-xattr.symlink)
+          |}];
+        set_and_print ~follow_symlinks:true ~path:symlink_to_path ~name ~value:"bar" ();
+        [%expect {| Ok |}];
+        get_and_print ~follow_symlinks:false ~path:symlink_to_path ~name;
+        [%expect {| ENOATTR |}];
+        get_and_print ~follow_symlinks:true ~path:symlink_to_path ~name;
+        [%expect {| (Ok bar) |}];
+        Unix.unlink symlink_to_path)
+    ;;
+
+    let%expect_test "roundtrip a binary blob that contains null characters to confirm \
+                     that they are preserved"
+      =
+      with_tmpfile (fun path ->
+        let name = "user.foo" in
+        get_and_print ~follow_symlinks:false ~path ~name;
+        [%expect {| ENOATTR |}];
+        set_and_print ~follow_symlinks:false ~path ~name ~value:"foo\000\nbar\000" ();
+        [%expect {| Ok |}];
+        get_and_print ~follow_symlinks:false ~path ~name;
+        [%expect {| (Ok "foo\000\nbar\000") |}])
+    ;;
+
     let%expect_test "test setxattr [`Create] semantics" =
       with_tmpfile (fun path ->
         let name = "user.foo" in
-        let set_and_create () = set_and_print ~how:`Create ~path ~name ~value:"blah" () in
+        let set_and_create () =
+          set_and_print ~how:`Create ~follow_symlinks:true ~path ~name ~value:"blah" ()
+        in
         set_and_create ();
         [%expect {| Ok |}];
-        get_and_print ~path ~name;
+        get_and_print ~follow_symlinks:true ~path ~name;
         [%expect {| (Ok blah) |}];
         set_and_create ();
         [%expect {| EEXIST |}])
@@ -508,37 +605,40 @@ let%test_module "getxattr and setxattr" =
       with_tmpfile (fun path ->
         let name = "user.foo" in
         let set_with_replace () =
-          set_and_print ~how:`Replace ~path ~name ~value:"xyz" ()
+          set_and_print ~how:`Replace ~follow_symlinks:true ~path ~name ~value:"xyz" ()
         in
         set_with_replace ();
         [%expect {| ENOATTR |}];
-        set_and_print ~how:`Create ~path ~name ~value:"bar" ();
+        set_and_print ~how:`Create ~follow_symlinks:true ~path ~name ~value:"bar" ();
         [%expect {| Ok |}];
-        get_and_print ~path ~name;
+        get_and_print ~follow_symlinks:true ~path ~name;
         [%expect {| (Ok bar) |}];
         set_with_replace ();
         [%expect {| Ok |}];
-        get_and_print ~path ~name;
+        get_and_print ~follow_symlinks:true ~path ~name;
         [%expect {| (Ok xyz) |}])
     ;;
 
     let%expect_test "test getxattr and setxattr on a non-existent file" =
       let path = "some-file-that-doesnt-exist" in
       let name = "user.foo" in
-      expect_error (fun () -> set_and_print ~path ~name ~value:"xyz" ());
+      expect_error (fun () ->
+        set_and_print ~follow_symlinks:true ~path ~name ~value:"xyz" ());
       [%expect
         {|
-      (Unix.Unix_error
-       "No such file or directory"
-       setxattr
-       some-file-that-doesnt-exist) |}];
-      expect_error (fun () -> get_and_print ~path ~name);
+        (Unix.Unix_error
+         "No such file or directory"
+         setxattr
+         some-file-that-doesnt-exist)
+        |}];
+      expect_error (fun () -> get_and_print ~follow_symlinks:true ~path ~name);
       [%expect
         {|
-      (Unix.Unix_error
-       "No such file or directory"
-       getxattr
-       some-file-that-doesnt-exist) |}]
+        (Unix.Unix_error
+         "No such file or directory"
+         getxattr
+         some-file-that-doesnt-exist)
+        |}]
     ;;
   end)
 ;;
@@ -564,26 +664,26 @@ let%test_unit "peer_credentials" =
       (Filename_unix.temp_file "linux_ext" "")
       ~finally:Unix.unlink
       ~f:(fun fname ->
-        (let fd = Unix.openfile fname ~mode:[ O_RDONLY ] in
-         try
-           ignore (peer_credentials fd : Peer_credentials.t);
-           failwith "peer credential on non socket should have raised"
-         with
-         | Unix.Unix_error (ENOTSOCK, _, _) -> ());
-        with_listening_server_unix_socket (fname ^ ".peercredsocket") ~f:(fun fname ->
-          let client_sock = Unix.socket ~domain:PF_UNIX ~kind:SOCK_STREAM ~protocol:0 () in
-          let rec connect count =
-            try Unix.connect client_sock ~addr:(ADDR_UNIX fname) with
-            | Unix_error (ECONNREFUSED, _, _) when count < 100 ->
-              (* the server might not have listened yet *)
-              ignore (Unix.nanosleep 0.1 : float);
-              connect (count + 1)
-          in
-          connect 0;
-          let p = peer_credentials client_sock in
-          [%test_eq: Pid.t] p.pid (Unix.getpid ());
-          [%test_eq: int] p.uid (Unix.getuid ());
-          [%test_eq: int] p.gid (Unix.getgid ())))
+      (let fd = Unix.openfile fname ~mode:[ O_RDONLY ] in
+       try
+         ignore (peer_credentials fd : Peer_credentials.t);
+         failwith "peer credential on non socket should have raised"
+       with
+       | Unix.Unix_error (ENOTSOCK, _, _) -> ());
+      with_listening_server_unix_socket (fname ^ ".peercredsocket") ~f:(fun fname ->
+        let client_sock = Unix.socket ~domain:PF_UNIX ~kind:SOCK_STREAM ~protocol:0 () in
+        let rec connect count =
+          try Unix.connect client_sock ~addr:(ADDR_UNIX fname) with
+          | Unix_error (ECONNREFUSED, _, _) when count < 100 ->
+            (* the server might not have listened yet *)
+            ignore (Unix.nanosleep 0.1 : float);
+            connect (count + 1)
+        in
+        connect 0;
+        let p = peer_credentials client_sock in
+        [%test_eq: Pid.t] p.pid (Unix.getpid ());
+        [%test_eq: int] p.uid (Unix.getuid ());
+        [%test_eq: int] p.gid (Unix.getgid ())))
 ;;
 
 let%expect_test "cpu_list_of_string_exn" =
@@ -653,7 +753,8 @@ let%expect_test "TCP_CONGESTION" =
     (raised (Unix.Unix_error "Invalid argument" setsockopt ""))
     (raised (Unix.Unix_error "Invalid argument" setsockopt ""))
     (raised (Unix.Unix_error "No such file or directory" setsockopt ""))
-    (raised (Unix.Unix_error "No such file or directory" setsockopt "")) |}];
+    (raised (Unix.Unix_error "No such file or directory" setsockopt ""))
+    |}];
   (* We need to close the socket to clean up the test... *)
   Unix.close sock;
   (* But it also gives us an opportunity to demonstrate correct behaviour (gracefully
@@ -664,5 +765,6 @@ let%expect_test "TCP_CONGESTION" =
   [%expect
     {|
     (raised (Unix.Unix_error "Bad file descriptor" getsockopt ""))
-    (raised (Unix.Unix_error "Bad file descriptor" setsockopt "")) |}]
+    (raised (Unix.Unix_error "Bad file descriptor" setsockopt ""))
+    |}]
 ;;
