@@ -7,7 +7,7 @@ let%test _ =
   [%equal: [ `Native | `Bytecode ]]
     (Sys_unix.execution_mode ())
     (if String.is_suffix argv.(0) ~suffix:".exe"
-     || String.is_suffix argv.(0) ~suffix:".native"
+        || String.is_suffix argv.(0) ~suffix:".native"
      then `Native
      else `Bytecode)
 ;;
@@ -25,5 +25,6 @@ let%expect_test _ =
   print_s [%sexp ([%equal: string array] (Sys.get_argv ()) old_sys_argv : bool)];
   [%expect {|
     (THIS IS A TEST)
-    true |}]
+    true
+    |}]
 ;;
